==> haskell-wai-app-static-3.1.6.1-19-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-D3WwXNFbseJITVrBkAuXiu
key: wai-app-static-3.1.6.1-D3WwXNFbseJITVrBkAuXiu
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: 6321778e69eb925b961f51bfebdda0c7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-D3WwXNFbseJITVrBkAuXiu
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.21-dNElXZJA0h9qauO3Ci5I8
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-D6CtKivKkrH825hCr2j5VF
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    memory-0.14-OFv2Lq6BLAGkAA3O98CQC
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.0.0-IErSQpKP3j4oJy1jHSvi1
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    wai-3.2.1.1-1tyXra1bExD5E5dzTFMy2m
    wai-extra-3.0.19-3XeYITdIwBt3XvQFjyyvt6
    warp-3.2.9-7GWv5zPVIbw2Z87Xu6AzXn
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.1-24-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-ETIWyX0ndVg2nHnsVnqWsR
key: wai-app-static-3.1.6.1-ETIWyX0ndVg2nHnsVnqWsR
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: dda421a6440d89c2c13b15af7c6ac999
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-ETIWyX0ndVg2nHnsVnqWsR
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.21-H8Zyk55iekJ2xfDZlsLCTV
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-BkDGiITUvM4C7RcwihYK3
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    memory-0.14-1UtwNv7NYkX9dHSkMG3pxY
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.0.0-IErSQpKP3j4oJy1jHSvi1
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    wai-extra-3.0.19.1-Atmlzc1gekK6Q3AM6YTjpP
    warp-3.2.9-4a6ooOXe4CeI3DiHXEQz1V
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
